==> oddmuse-1.637.tar.gz: oddmuse-1.637/brazilian-portuguese-utf8.pl <==
# UTF-8 encoded Brazilian Portuguese language file for use with Oddmuse
#
# Copyright (c) 2003  Marcelo Toledo <rw@locked.org>.
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt.
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
# This translation was last checked for Oddmuse version 1.195.
#
$ModulesDescription .= '<p>$Id: brazilian-portuguese-utf8.pl,v 1.1 2005/10/10 18:58:42 as Exp $</p>';
%Translate = split(/\n/,<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.
Leitura não permitida: usuário, ip, ou rede está bloqueada.
Could not create %s
Não foi possivel criar %s
Invalid UserName %s: not saved.
Usuário inválido %s: nada salvo.
UserName must be 50 characters or less: not saved
NomeUsuario deve ter 50 caracteres ou menos: nada salvo
This page contains an uploaded file:

XML::RSS is not available on this system.
XML::RSS não existe neste sistema
diff
diferenças
history
história
%s returned no data, or LWP::UserAgent is not available.

RSS parsing failed for %s

No items found in %s.

 . . . . 

Click to edit this page

image
imagem
download

CGI Internal error: %s
Erro CGI interno: %s
Invalid action parameter %s
Parametro de ação inválido %s
Invalid URL.
URL inválida.
Page name is missing
Falta o nome da página
Page name is too long: %s
Nome de página é muito longo: %s
Invalid Page %s
Página %s invália
Invalid Page %s (must not end with .db)
Página %s inválida (não pode terminar com .db)
Invalid Page %s (must not end with .lck)
Página %s inválida (não pode terminar com .lck)
Page name may not contain space characters: %s
Nome de página não pode conter espaço: %s
Preview:
Prever:
Preview only, not yet saved
Visualização apenas, nada foi salvo
Please go on to %s.
Por favor vá para %s
Could not open %s log file
Não foi possivel abrir o arquivo %s de log
Error was
Erro foi
Note: This error is normal if no changes have been made.
NOTA: Esse erro é normal se nenhuma alteração foi feita.
Could not open old %s log file
Não foi possivel abrir o antigo arquivo %s de log
No updates since %s
Nenhuma atualização desde %s
Updates since %s
Atualizações desde %s
Updates in the last %s days
Atualizações nos últimos %s dias
Updates in the last %s day
Atualizações no último %s dia
for %s only
para %s apenas
List latest change per page only
Mostra só as últimas modificações por página
List all changes
Mostra todas as modificações
List only major changes
Mostra só as modificações maiores
Include minor changes
Inclui também as modificações menores
%s days
%s dias
List later changes
Mostra novas modificações
Filters
Filtros
Title:

Title and Body:

Username:
Usuário:
Host:

Language:
Língua:
Go!
Ir!
(minor)
(mínima)
rollback

new
novo
from %s
de %s
This page is too big to send over RSS.

History of %s
Histórico de %s
Compare
Comparar
Revision %s
Revisão %s
by
por
Rolling back changes

Missing target for rollback.

Target for rollback is too far back.

Rollback to %s

%s rolled back

Index of all pages
Índice de todas as páginas
Wiki Version
Mostrando versão do Wiki
Unlock Wiki
Destravando
Password
Senha
Run maintenance
Manutenção
Unlock site
Desbloquear sítio
Lock site
Bloquear sítio
Install CSS

Unlock %s
Desbloquear %s
Lock %s
Bloquear %s
Administration

Actions:

Important pages:

To mark a page for deletion, put <strong>%s</strong> on the first line.

[Home]
[Ínicio]
redirected from %s
redirecionado de %s
Click to search for references to this page

Cookie: 

Warning
Atenção
Database is stored in temporary directory %s
Banco de dados é armazenado no diretório temporario %s
%s seconds
%s segundos
The same page on other sites:
A mesma página noutro lado:
EditNearLinks

Last edited
Ultima edição
Edited
Editado
by %s
de %s
(diff)
(diff)
Edit revision %s of this page
Edite a revisão %s desta página
Edit this page
Edite esta página
e

This page is read-only
Esta página é apenas para leitura
View other revisions
Veja outras revisões
View current revision
Veja a versão corrente
View all changes
Veja todas os câmbios
Homepage URL:

s
s
Save
Salvar
Preview
Prever
Search:
Busca:
f

Replace:

Validate HTML
Validar HTML
Validate CSS
Validar CSS
Difference (from revision %1 to %2)
Diferença (entre a revisão %1 e %2)
revision %s
revisão %s
current revision
versão corrente
Difference (from prior %s revision)
Diferença (anterior à %s revisão)
major
importante
minor
simples
No diff available.
Nenhum diff disponivel.
The two revisions are the same.

Old revision:
Revisão antiga:
Changed:
Alterado:
Removed:
Removido:
Added:
Adicionado:
to
para
Revision %s not available
Revisão %s não disponivel
showing current revision instead
ao invéz mostrando versão corrente
Showing revision %s
Mostrando versão %s
Cannot save a nameless page.
Não se pode salvar uma página sem nome.
Cannot save a page without revision.
Não se pode salvar uma página sem revisão.
Cannot open %s
Não foi possível abrir %s
Cannot write %s
Não foi possível escrever %s
Cannot create %s

Could not get %s lock
Não foi possível conseguir a trava %s
This operation may take several seconds...
Essa operação pode demorar alguns segundos...
Forced unlock of %s lock.
Trava forcada de %s
No unlock required.
Nenhum destravamento necessário.
%s hours ago
%s horas atras
1 hour ago
1 hora atras
%s minutes ago
%s minutos atras
1 minute ago
1 minuto atras
%s seconds ago
%s segundos atras
1 second ago
1 segundo atras
just now
agora
Edit Denied

Editing not allowed: user, ip, or network is blocked.
Edição não permitida: usuário, ip, ou rede está bloqueada.
Contact the wiki administrator for more information.
Contate o administrador do wiki para maiores informações.
The rule %s matched for you.
A regra %s confere para você.
See %s for more information.
Para mais informações, veja %s.
Editing not allowed: %s is read-only.
Edição não permitida: %s is apenas para leitura.
Only administrators can upload files.

Editing revision %s of
Editando revisão %s de
Editing %s
Editando %s
Editing old revision %s.
Editando antiga revisão %s.
Saving this page will replace the latest revision with this text.
Salvando esta página irá substituir a ultima revisão com esse texto.
Summary:
Sumário:
This change is a minor edit.
Esta atualização é miníma.
Replace this file with text.
Escrever texto em vez do archivo presente.
Replace this text with a file.
Usar um archivo em vez do texto presente.
File to upload: 
Archivo à usar: 
Files of type %s are not allowed.

Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
Sua senha é salva em um cookie, caso esteja ativado no seu navegador. Cookies podem se perder se você conectar de outra maquina, outra conta, ou outro software.
You are currently an administrator on this site.
Você é atualmente um administrador neste site.
You are currently an editor on this site.
Você é atualmente um editor neste site.
You are a normal user on this site.
Você é um usuario normal neste site.
Your password does not match any of the  administrator or editor passwords.
Sua senha não confere com nenhuma dos administradores ou editores.
Password:
Senha:
This site does not use admin or editor passwords.
Este site não usa senhas de administrador ou editor.
This operation is restricted to site editors only...
Essa operação é restrita aos editores do site...
This operation is restricted to administrators only...
Essa operação é restrita aos administradores...
Rule "%1" matched "%2" on this page.

Without normal pages

Include normal pages

Without permanent anchors

Include permanent anchors

Without near pages

Include near pages

(for %s)
(para %s)
Filter:

%s pages found.
%s páginas encontradas.
Replaced: %s
Substituído: %s
Search for: %s
Buscar por: %s
View changes for these pages
Ver câmbios para estas págians
Search sites on the %s as well
Estender a busca para os sítios no %s
and
e
or
ou
Fetching results from %s:
Buscando os resultados de %s:
Near pages:
Páginas próximas:
last updated
ultima atualização
Complete Content
Conteúdo completo
The main page is %s.
A página principal é %s.
Comments on this page
Commentários sobre esta página
Editing not allowed for %s.
Edição não permitida para %s.
SampleUndefinedPage
ExemploPaginaNaoDefinida
%s cannot be defined.
%s não pode ser definida.
Sample_Undefined_Page
Exemplo_Pagina_Nao_Definida
[[%s]] cannot be defined.
[[%s]] não pode ser definida.
Only an administrator can create %s.
Só administradores podem criar a página %s.
Transfer Error: %s

Browser reports no file info.

Browser reports no file type.

The page contains banned text.

No changes to be saved.

This page was changed by somebody else %s.
Esta página foi editada por outra pessoa %s.
The changes conflict.  Please check the page again.

Please check whether you overwrote those changes.
Se faz favor controle se você  esses câmbios.
Anonymous
Anônimo
Cannot delete the index file %s.

Please check the directory permissions.

Your changes were not saved.

Could not get a lock to merge!
Não foi possivel pegar a trava para combinar!
you
o que você escreveu
ancestor
o que já estava
other
o que a outra pessoa escreveu
Run Maintenance

Maintenance not done.
Manutenção não concluída.
(Maintenance can only be done once every 12 hours.)
(Manutenção pode ser feita apenas a cada 12 horas.)
Remove the "maintain" file or wait.
Romove o arquivo "manter" ou esperar.
Main lock obtained.
Trava principal obtida.
Expiring keep files and deleting pages marked for deletion
Expirando mantém arquivos e deletando páginas marcadas para deletar
not deleted: 
não deletado: 
deleted
deletado
Moving part of the %s log file.
Movendo parte de %s arquivo de log.
Moving %s log entries.
Movendo %s entrada de log.
Getting page index file for %s.

Main lock released.
Trava principal liberado.
Set or Remove global edit lock
Marque ou Remova trava global de edição
Edit lock created.
Trava de edição criada.
Edit lock removed.
Trava de edição removido.
Set or Remove page edit lock
Marque ou Remova trava de ediçao de páginas
Missing page id to lock/unlock...
Faltando id da página para travar/destravar...
Lock for %s created.
Trava para %s criado.
Lock for %s removed.
Trava para %s removido:
Displaying Wiki Version

Show dependencies

Inter links:

Near links:

Show parsed link data

Too many connections by %s
Muitas conexões de %s
Please do not fetch more than %1 pages in %2 seconds.
Se faz favor não busque mais do que %1 páginas em %2 segundos.
Check whether the web server can create the directory %s and whether it can create files in it.

anchor first defined here: %s

Click to search for references to this permanent anchor

the page %s also exists
a página %s também existe
Copy one of the following stylesheets to %s:

Deleting %s

Deleted %s

Renaming %1 to %2.

The page %s does not exist
A página %s não existe
The page %s already exists
A página %s já existe
Cannot rename %1 to %2

Renamed to %s

Renamed from %s

Renamed %1 to %2.

Immediately delete %s

Rename %s to:

Cannot highlight the language %s.

Recent Visitors
Visitantes recentes
some action

was here

and read

Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.

The match parameter is missing.

Page Collection for %s

Previous
Prévio
Next
Próximo
Calendar %s
Calendário para %s
Clustermap

Pages without a Cluster

Comments on 

Comment on 

Compilation for %s

Compilation tag is missing a regular expression.

Despamming pages

Cannot find revision %s.

Revert to revision %1: %2

Marked as %s.

Cannot find unspammed revision.

Add Comment

ordinary changes

Footnotes:

Could not find %1.html template in %2

Only Editors are allowed to see hidden pages.

Only Admins are allowed to see hidden pages.

image: %s
imagem: %s
Index

Languages:
Línguas:
Show!
Mostrar!
Define

Full Link List

Template without parameters

The template %s is either empty or does not exist.

Register for %s

Please choose a username of the form "FirstLast" using your real name.

The passwords do not match.

The password must be at least %s characters.

That email address is invalid.

The username %s has already been registered.

Your registration for %s has been submitted.

  Please allow time for the webmaster to approve your request.

  An email has been sent to "%s" with further instructions.

There was an error saving your registration.

An account was created for %s.

Login to %s

Username and/or password are incorrect.

Logged in as %s.

Logout of %s

<p>Logout of %s?</p>

Logged out of %s

You are now logged out.

Register a new account

Login

Logout

Who am I?

Forgot your password?

Change your password

Approve pending registrations

Confirm Registration for %s

%s, your registration has been approved. You can now use your password to login and edit this wiki.

Confirmation failed.  Please email %s for help.

Who Am I?

You are logged in as %s.

You are not logged in.

Reset Password

The password for %s was reset.  It has been emailed to the address on file.

There was an error resetting the password for %s

The username "%s" does not exist.

Reset Password for %s

<p>Reset Password?</p>

Change Password for %s

<p>Change Password?</p>

Your current password is incorrect.

Your password has been changed.

Approve Pending Registrations for %s

%s has been approved.

There was an error approving %s.

<ul>

<li>%1 - %2</li>

</ul>

There are no pending registrations.

Clearing Cache

Done.

Generating Link Database

The 404 handler extension requires the link data extension (links.pl).

LocalMap

No page id for action localmap

Requested page %s does not exist

Local Map for %s

view

Self-ban by %s

You have banned your own IP.

Orphan List

Trail: 

None
Nenhum
Type
Tipo
Permalink to "%s"

Portrait

You did not answer correctly.

All Referrers

Referrers

Rebuild index for searching

Rebuilding Index

Search::FreeText is not available on this system.

Rebuilding index not done.

(Rebuilding the index can only be done once every 12 hours.)

Search term missing.

Result pages: 

(%s results)

Slideshow:%s

Static Copy

Back to %s
Voltar para %s
Copy to %1 succeeded: %2.

Copy to %1 failed: %2.

Tag

Alternatively, use one of the following templates:

Thread: %s

ID parameter is missing.

Thread %s does not exist.

Page %s does not contain a thread.

Add

URL parameter is missing.

Add to %s thread

Below:

URL:

Name:
Nome:
Failed to remove %s

Contents

This page is a translation of %s. 

The translation is up to date.

The translation is outdated.

The page does not exist.
Esta página não existe.
http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s

http://www.amazon.com/exec/obidos/ISBN=%s
http://www.amazon.de/exec/obidos/ISBN=%s
alternate
alternativa
http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search
busca
Upload of %s file

Blog
Blog
Matching pages:

New

Edit %s.

END_OF_TRANSLATION

==> oddmuse-1.662.tar.gz: oddmuse-1.662/brazilian-portuguese-utf8.pl <==
# UTF-8 encoded Brazilian Portuguese language file for use with Oddmuse
#
# Copyright (c) 2003  Marcelo Toledo <rw@locked.org>.
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt.
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
# This translation was last checked for Oddmuse version 1.195.
#
$ModulesDescription .= '<p>$Id: brazilian-portuguese-utf8.pl,v 1.3 2006/05/10 22:52:16 as Exp $</p>';
%Translate = split(/\n/,<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.
Leitura não permitida: usuário, ip, ou rede está bloqueada.
Could not create %s
Não foi possivel criar %s
Invalid UserName %s: not saved.
Usuário inválido %s: nada salvo.
UserName must be 50 characters or less: not saved
NomeUsuario deve ter 50 caracteres ou menos: nada salvo
This page contains an uploaded file:
Esta página contém um arquivo carregado:
Recursive include of %s!

XML::RSS is not available on this system.
XML::RSS não existe neste sistema
diff
diferenças
history
histórico
%s returned no data, or LWP::UserAgent is not available.

RSS parsing failed for %s

No items found in %s.

 . . . . 

Click to edit this page
Clique para editar esta página
image
imagem
download
download
CGI Internal error: %s
Erro interno de CGI : %s
Invalid action parameter %s
Parametro de ação inválido %s
Invalid URL.
URL inválida.
Page name is missing
Falta o nome da página
Page name is too long: %s
Nome de página é muito longo: %s
Invalid Page %s (must not end with .db)
Página %s inválida (não pode terminar com .db)
Invalid Page %s (must not end with .lck)
Página %s inválida (não pode terminar com .lck)
Invalid Page %s
Página %s invália
Preview:
Prever:
Preview only, not yet saved
Visualização apenas, nada foi salvo
Please go on to %s.
Por favor vá para %s
Could not open %s log file
Não foi possivel abrir o arquivo %s de log
Error was
Erro foi
Note: This error is normal if no changes have been made.
Obaservação: Esse erro é normal se nenhuma alteração foi feita.
Could not open old %s log file
Não foi possível abrir o antigo arquivo %s de log
No updates since %s
Nenhuma atualização desde %s
Updates since %s
Atualizações desde %s
Updates in the last %s days
Atualizações nos últimos %s dias
Updates in the last %s day
Atualizações no último %s dia
for %s only
para %s apenas
List latest change per page only
Mostra só as últimas modificações por página
List all changes
Mostra todas as modificações
List only major changes
Mostra só as modificações maiores
Include minor changes
Inclui também as modificações menores
%s days
%s dias
List later changes
Mostra novas modificações
Filters
Filtros
Title:
Título
Title and Body:
Título e Corpo:
Username:
Usuário:
Host:

Language:
Língua:
Go!
Ir!
(minor)
(mínima)
rollback
desfazer
new
novo
from %s
de %s
This page is too big to send over RSS.
Esta página é grande demais para enviar por RSS.
History of %s
Histórico de %s
Compare
Comparar
Revision %s
Revisão %s
by
por
Rolling back changes
Desfazendo mudanças
Missing target for rollback.
Faltou alvo para desfazer mudança.
Target for rollback is too far back.
Alvo para desfazer mudança é muito antigo.
Rollback to %s
Desfazer para %s
%s rolled back
%s desfeito
Index of all pages
Índice de todas as páginas
Wiki Version
Versão do Wiki
Unlock Wiki
Desbloquear Wiki
Password
Senha
Run maintenance
Manutenção
Unlock site
Desbloquear sítio
Lock site
Bloquear sítio
Install CSS
Instalar CSS
Unlock %s
Desbloquear %s
Lock %s
Bloquear %s
Administration
Administração
Actions:
Ações
Important pages:
Páginas importantes:
To mark a page for deletion, put <strong>%s</strong> on the first line.
Para marcar uma página para exclusão, escreva <strong>%s</strong> na primeira linha
[Home]
[Ínicio]
redirected from %s
redirecionado de %s
Click to search for references to this page
Clique para buscar referência a esta página
Cookie: 
Cookie:
Warning
Atenção
Database is stored in temporary directory %s
Banco de dados é armazenado no diretório temporario %s
%s seconds
%s segundos
The same page on other sites:
A mesma página noutro lado:
EditNearLinks

Last edited
Ultima edição
Edited
Editado
by %s
de %s
(diff)
(diff)
Edit revision %s of this page
Editar a revisão %s desta página
Edit this page
Editar esta página
e

This page is read-only
Esta página é apenas para leitura
View other revisions
Ver outras revisões
View current revision
Ver a versão corrente
View all changes
Ver todas as mudanças
Homepage URL:

s
s
Save
Salvar
p

Preview
Prever
Search:
Buscar:
f

Replace:
Substituir:
Validate HTML
Validar HTML
Validate CSS
Validar CSS
Difference (from revision %1 to %2)
Diferença (entre a revisão %1 e %2)
revision %s
revisão %s
current revision
versão corrente
Difference (from prior %s revision)
Diferença (anterior à %s revisão)
major
importante
minor
simples
No diff available.
Nenhum diff disponivel.
The two revisions are the same.
As duas revisões são idênticas
Old revision:
Revisão antiga:
Changed:
Alterado:
Removed:
Removido:
Added:
Adicionado:
to
para
Revision %s not available
Revisão %s não disponivel
showing current revision instead
ao invéz mostrando versão corrente
Showing revision %s
Mostrando versão %s
Cannot save a nameless page.
Não se pode salvar uma página sem nome.
Cannot save a page without revision.
Não se pode salvar uma página sem revisão.
Cannot open %s
Não foi possível abrir %s
Cannot write %s
Não foi possível escrever %s
Cannot create %s
Não foi possível criar %s
Could not get %s lock
Não foi possível conseguir a trava %s
The lock was created %s.
O bloqueio foi criado %s.
This operation may take several seconds...
Essa operação pode demorar alguns segundos...
Forced unlock of %s lock.
Desbloqueio forcado de %s
No unlock required.
Nenhum desbloqueio necessário.
%s hours ago
%s horas atrás
1 hour ago
1 hora atrás
%s minutes ago
%s minutos atrás
1 minute ago
1 minuto atrás
%s seconds ago
%s segundos atrás
1 second ago
1 segundo atrás
just now
agora
Edit Denied
Edição negada
Editing not allowed: user, ip, or network is blocked.
Edição não permitida: usuário, ip, ou rede está bloqueada.
Contact the wiki administrator for more information.
Contate o administrador do wiki para maiores informações.
The rule %s matched for you.
A regra %s confere para você.
See %s for more information.
Para mais informações, veja %s.
Editing not allowed: %s is read-only.
Edição não permitida: %s is apenas para leitura.
Only administrators can upload files.
Somente administradores podem carregar arquivos.
Editing revision %s of
Editando revisão %s de
Editing %s
Editando %s
Editing old revision %s.
Editando antiga revisão %s.
Saving this page will replace the latest revision with this text.
Salvando esta página irá substituir a ultima revisão com esse texto.
Summary:
Sumário:
This change is a minor edit.
Esta atualização é miníma.
Replace this file with text.
Escrever texto em vez do arquivo presente.
Replace this text with a file.
Usar um arquivo em vez do texto presente.
File to upload: 
Arquivo à usar: 
Files of type %s are not allowed.
Arquivos do tipo %s não são permitidos.
Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
Sua senha é salva em um cookie, caso esteja ativado no seu navegador. Cookies podem se perder se você conectar de outra maquina, outra conta, ou outro software.
You are currently an administrator on this site.
Você é atualmente um administrador neste site.
You are currently an editor on this site.
Você é atualmente um editor neste site.
You are a normal user on this site.
Você é um usuario normal neste site.
Your password does not match any of the  administrator or editor passwords.
Sua senha não confere com nenhuma dos administradores ou editores.
Password:
Senha:
This site does not use admin or editor passwords.
Este site não usa senhas de administrador ou editor.
This operation is restricted to site editors only...
Essa operação é restrita aos editores do site...
This operation is restricted to administrators only...
Essa operação é restrita aos administradores...
Rule "%1" matched "%2" on this page.

Without normal pages

Include normal pages

Without permanent anchors

Include permanent anchors

Without near pages

Include near pages

(for %s)
(para %s)
Filter:
Filtro:
%s pages found.
%s páginas encontradas.
Replaced: %s
Substituído: %s
Search for: %s
Buscar por: %s
View changes for these pages
Ver câmbios para estas págians
Search sites on the %s as well
Estender a busca para os sítios no %s
and
e
or
ou
Fetching results from %s:
Buscando os resultados de %s:
Near pages:
Páginas próximas:
last updated
ultima atualização
Complete Content
Conteúdo completo
The main page is %s.
A página principal é %s.
Comments on this page
Commentários sobre esta página
Editing not allowed for %s.
Edição não permitida para %s.
SampleUndefinedPage
ExemploPaginaNaoDefinida
%s cannot be defined.
%s não pode ser definida.
Sample_Undefined_Page
Exemplo_Pagina_Nao_Definida
[[%s]] cannot be defined.
[[%s]] não pode ser definida.
Only an administrator can create %s.
Só administradores podem criar a página %s.
Transfer Error: %s
Erro de transferência: %s
Browser reports no file info.

Browser reports no file type.

The page contains banned text.

No changes to be saved.
Nenhuma mudança para ser salva.
This page was changed by somebody else %s.
Esta página foi editada por outra pessoa %s.
The changes conflict.  Please check the page again.

Please check whether you overwrote those changes.
Se faz favor controle se você  esses câmbios.
Anonymous
Anônimo
Cannot delete the index file %s.
Não foi possível excluir o arquivo de índice %s.
Please check the directory permissions.
Cheque as permissões do diretório.
Your changes were not saved.
Suas mudanças não foram salvas
Could not get a lock to merge!
Não foi possivel bloquear para combinar!
you
o que você escreveu
ancestor
o que já estava
other
o que a outra pessoa escreveu
Run Maintenance
Executar Manutenção
Maintenance not done.
Manutenção não concluída.
(Maintenance can only be done once every 12 hours.)
(Manutenção pode ser feita apenas a cada 12 horas.)
Remove the "maintain" file or wait.
Romove o arquivo "manter" ou esperar.
Main lock obtained.
Trava principal obtida.
Expiring keep files and deleting pages marked for deletion
Expirando mantém arquivos e deletando páginas marcadas para deletar
not deleted: 
não excluído: 
deleted
excluído
Moving part of the %s log file.
Movendo parte de %s arquivo de log.
Moving %s log entries.
Movendo %s entrada de log.
Getting page index file for %s.

Main lock released.
Trava principal liberado.
Set or Remove global edit lock
Marque ou Remova trava global de edição
Edit lock created.
Trava de edição criada.
Edit lock removed.
Trava de edição removido.
Set or Remove page edit lock
Marque ou Remova trava de ediçao de páginas
Lock for %s created.
Trava para %s criado.
Lock for %s removed.
Trava para %s removido:
Displaying Wiki Version
Mostrando a versão do Wiki
Show dependencies
Mostrar dependências
Inter links:

Near links:

Show parsed link data

Too many connections by %s
Muitas conexões de %s
Please do not fetch more than %1 pages in %2 seconds.
Se faz favor não busque mais do que %1 páginas em %2 segundos.
Check whether the web server can create the directory %s and whether it can create files in it.

anchor first defined here: %s

Click to search for references to this permanent anchor

the page %s also exists
a página %s também existe
Copy one of the following stylesheets to %s:

Deleting %s
Excluindo %s
Deleted %s
Excluído
Renaming %1 to %2.
Renomeando %1 para %2.
The page %s does not exist
A página %s não existe
The page %s already exists
A página %s já existe
Cannot rename %1 to %2
Não foi possível renomear %1 para %2
Renamed to %s
Renomeado para %s
Renamed from %s
Renomeado de %s
Renamed %1 to %2.
Renomeado %1 para %2
Immediately delete %s
Excluir imadiatamente %s
Rename %s to:
Renomear %s para:
Learn more...
Leia mais...
Cannot highlight the language %s.
Não foi possível destacar a linguagem %s.
Recent Visitors
Visitantes recentes
some action

was here

and read

Illegal year value: Use 0001-9999

The match parameter is missing.

Page Collection for %s

Previous
Prévio
Next
Próximo
Calendar %s
Calendário para %s
Su
Do
Mo
Se
Tu
Te
We
Qu
Th
Qu
Fr
Se
Sa
Sa
January
Janeiro
February
Fevereiro
March
Março
April
Abril
May
Maio
June
Junho
July
Julho
August
Agosto
September
Setembro
October
Outubro
November
Novembro
December
Dezembro
Clustermap

Pages without a Cluster

Comments on 
Comentários sobre 
Comment on 
Comentar sobre 
Compilation for %s

Compilation tag is missing a regular expression.

Despamming pages

Cannot find revision %s.

Revert to revision %1: %2
Reverter para revisão %1: %2
Marked as %s.
Marcado como %s.
Cannot find unspammed revision.

Add Comment
Adicionar Comentário
ordinary changes

Footnotes:
Notas de rodapé: 
Could not find %1.html template in %2

Only Editors are allowed to see this hidden page.

Only Admins are allowed to see this hidden page.

Index

Languages:
Línguas:
Show!
Mostrar!
Define

Full Link List

Template without parameters

The template %s is either empty or does not exist.

 -- defined on %s

Local names defined on %1: %2

Register for %s

Please choose a username of the form "FirstLast" using your real name.
Escolha um nome de usuário da forma "NomeSobrenome" usando o seu nome verdadeiro.
The passwords do not match.
As senhas não são iguais.
The password must be at least %s characters.
A senha dever ter no mínimo %s caracteres.
That email address is invalid.
Este endereço de email é inválido.
The username %s has already been registered.
O nome de usuário %s já foi registrado.
Your registration for %s has been submitted.

Please allow time for the webmaster to approve your request.

An email has been sent to "%s" with further instructions.

There was an error saving your registration.

An account was created for %s.

Login to %s

Username and/or password are incorrect.
Nome de usuário e/ou senha inválidos.
Logged in as %s.

Logout of %s

Logout of %s?

Logged out of %s

You are now logged out.

Register a new account

Login

Logout

Who am I?

Forgot your password?
Esqueceu sua senha?
Change your password
Mudar sua senha
Approve pending registrations
Aprovar rsgistros pendentes
Confirm Registration for %s
Confirmar resgistro para %s
%s, your registration has been approved. You can now use your password to login and edit this wiki.

Confirmation failed.  Please email %s for help.

Who Am I?
Quem sou eu?
You are logged in as %s.

You are not logged in.

Reset Password

The password for %s was reset.  It has been emailed to the address on file.

There was an error resetting the password for %s.

The username "%s" does not exist.

Reset Password for %s

Reset Password?

Change Password for %s

Change Password?

Your current password is incorrect.

Your password has been changed.

Approve Pending Registrations for %s

%s has been approved.
%s foi aprovado.
There was an error approving %s.

<ul>

<li>%1 - %2</li>

</ul>

There are no pending registrations.
Não há registros pendentes.
%s is not a legal name for a namespace

Clearing Cache

Done.

Generating Link Database

The 404 handler extension requires the link data extension (links.pl).

LocalMap

No page id for action localmap

Requested page %s does not exist

Local Map for %s

view

Self-ban by %s

You have banned your own IP.

Orphan List

Trail: 
Rastro: 
None
Nenhum
Type
Tipo
Permalink to "%s"

There was an error generating the pdf for %s.  Please report this to webmaster, but do not try to download again as it will not work.

Someone else is generating a pdf for %s.  Please wait a minute and then try again.

Download this page as PDF
Baixar esta página como PDF
Portrait
Retrato
You did not answer correctly.

All Referrers

Referrers

Tag

Rebuild index for searching

Tag Cloud

Search::FreeText is not available on this system.

Rebuilding index not done.

(Rebuilding the index can only be done once every 12 hours.)

 ... 

Search term missing.
Faltou o termo para a busca.
Result pages: 
Páginas de resultado: 
(%s results)

Slideshow:%s

Static Copy

Back to %s
Voltar para %s
Copy to %1 succeeded: %2.

Copy to %1 failed: %2.

Alternatively, use one of the following templates:

Thread: %s

ID parameter is missing.

Thread %s does not exist.

Page %s does not contain a thread.

Add
Adicionar
URL parameter is missing.

Add to %s thread

Below:
Abaixo:
URL:
URL:
Name:
Nome:
Failed to remove %s
Falha ao remover %s
Contents
Conteúdo
This page is a translation of %s. 
Esta página é uma tradução de %s. 
The translation is up to date.
A tradução está atualizada.
The translation is outdated.
A tradução está desatualizada.
The page does not exist.
Esta página não existe.
http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s

http://www.amazon.com/exec/obidos/ISBN=%s
http://www.amazon.de/exec/obidos/ISBN=%s
alternate
alternativa
http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search
busca
Upload of %s file

Blog
Blog
Matching pages:

New
Novo
Edit %s.
Editar %s.
END_OF_TRANSLATION
